utils::globalVariables(c(".", "context", "docname", "keyword",
                         "num_tokens", "post", "pre", "pre_trained", "term_count",
                         "transform_matrix", "typicality_score", "term",
                         "value", "feature", "N", "target",
                         "absdev", "p.value", "significant", "valueJitter",
                         "group", "featureID", "pattern", "token",
                         "contexts", "contexts_dem", "docid", "where",
                         "tmp_by", "lower.ci", "upper.ci", "tokens_subset",
                         "coefficient", "first_val", "sec_val", "val", "id", "i", "estimate", "std.error"))
